RDFCalendar.Store.Store

Package RDFCalendar :: Module Store :: Class Store |
[show private | hide private]
[frames | no frames]

## Class Store

    AbstractHandler --+
                      |
      AbstractStore --+
                      |
                  Store --+
                          |
                         Store

    A wrapper around a data store, providing convenient access for parsers and
    writers.

Method Summary
| ``get_attribute_name`(self, predicate)` Return the attribute name for the given store 'predicate' identifier.
| ``get_element_name`(self, predicate)` Return the element name for the given store 'predicate' identifier.
| `get_property_types_for_uriref(self, uriref)`
| `get_supported_item_types(self)`
| `get_urirefs_for_attribute(self, attribute)`
| `get_urirefs_for_item_type(self, item_type_name)`
| `get_urirefs_for_property_type(self, property_type_name)`
| `parse(self, f, name, uriref)`
| `parse_document_fragment(self, doc, root, uriref)`
| `supports_item_type(self, item_type_str)`
| `write_to_document(self, doc, root, main_node, nodes, qualifier, value_as_attribute)`
| `write_to_stream(self, stream, main_node, nodes, *args, **kw)`
Inherited from Store
| ``__init__`(self, store, impl, prefix)` Initialise the store with the given underlying 'store' and implementation 'impl'.
| ``add_attribute`(self, parent, label)` Add to the given 'parent' a special attribute node with the given 'label'.
| ``add_contains`(self, node, element)`
| ``add_name`(self, node, name)`
| ``add_node`(self, label, uriref)` Add a node using the given 'label' to indicate its type and an optional 'uriref' to provide an identity.
| ``add_value`(self, attribute, label, value)` Add to the given 'attribute', described by the given 'label', the specified 'value'.
| ``close`(self)` Close the underlying store.
| ``commit`(self)` Commit changes to the underlying store if appropriate.
| ``contexts`(self)` Return a list of contexts found in this store.
| ``get_context`(self, context)` Return a copy of this store which uses the given 'context' to constrain operations on the stored triples.
| ``get_label`(self, node)` Return a label representing the given 'node'.
| ``get_node_type`(self, node)` Return the type of the given 'node'.
| ``get_uid`(self, node)` Return the uid for the given 'node' (a store identifier).
| ``has_item`(self, uriref)`
| ``make_uid`(self, value)` Return a store identifier for the given plain uid 'value'.
| ``remove_context`(self, context)` Removes the specified 'context' from the database.
| ``remove_node`(self, node, deep)` Remove the given 'node' and its attributes from the store.
| ``rollback`(self)` Roll back changes to the underlying store if appropriate.

Class Variable Summary
`list` | `connector_labels` = `['related-to', 'organizer', 'attendee...`
`classobj` | `DuplicateResourceError` = `RDFCalendar.Parsers.DuplicateResourceError`
`str` | `prefix` = `'http://www.boddie.org.uk/ns/rdfcalendar/'`
`list` | `uriref_labels` = `['uri', 'related-to']`

Method Details

### get_attribute_name(self, predicate)
    Return the attribute name for the given store 'predicate' identifier.

### get_element_name(self, predicate)
    Return the element name for the given store 'predicate' identifier.

Class Variable Details

    ### connector_labels Type: `list` Value:
        ['related-to', 'organizer', 'attendee']

    ### prefix Type: `str` Value:
        'http://www.boddie.org.uk/ns/rdfcalendar/'

    ### uriref_labels Type: `list` Value:
        ['uri', 'related-to']

Generated by Epydoc 2.1 on Mon Mar 19 01:08:11 2007 | http://epydoc.sf.net